#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# MouseCraft
# send your bug reports to contact@dotslashplay.it
###

script_version=20240929.2

PLAYIT_COMPATIBILITY_LEVEL='2.30'

GAME_ID='mousecraft'
GAME_NAME='MouseCraft'

ARCHIVE_BASE_0_NAME='gog_mousecraft_2.1.0.7.sh'
ARCHIVE_BASE_0_MD5='5d99353d6ef0db693cc3a492cfb8ae4c'
ARCHIVE_BASE_0_SIZE='870000'
ARCHIVE_BASE_0_VERSION='1.20-gog2.1.0.7'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/mousecraft'

UNITY3D_NAME='MouseCraft'

CONTENT_PATH_DEFAULT='data/noarch/game'
## FIXME: The list of shipped plugins to include should be set using UNITY3D_PLUGINS
ARCHIVE_GAME0_BIN64_FILES="
${UNITY3D_NAME}_Data/Plugins/x86_64"
ARCHIVE_GAME0_BIN32_FILES="
${UNITY3D_NAME}_Data/Plugins/x86"

PACKAGES_LIST='
PKG_BIN64
PKG_BIN32
PKG_DATA'

PKG_BIN64_ARCH='64'
PKG_BIN32_ARCH='32'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'
PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
## TODO: The list of dependencies on native libraries should be completed
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libGLU.so.1
libstdc++.so.6'
PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers

launchers_generation 'PKG_BIN64'
launchers_generation 'PKG_BIN32'

# Build package

packages_generation
print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
