#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Stacking
# send your bug reports to contact@dotslashplay.it
###

script_version=20240930.1

PLAYIT_COMPATIBILITY_LEVEL='2.30'

GAME_ID='stacking'
GAME_NAME='Stacking'

ARCHIVE_BASE_0_NAME='Stacking-Linux-2013-06-04-setup.bin'
ARCHIVE_BASE_0_MD5='4194bb869d537d40da7ad7f65b1102ed'
ARCHIVE_BASE_0_SIZE='1600000'
ARCHIVE_BASE_0_VERSION='130604-humble160616'
ARCHIVE_BASE_0_URL='https://www.humblebundle.com/store/stacking'

CONTENT_PATH_DEFAULT='data'
CONTENT_GAME_BIN_FILES='
Stack.bin.x86'
## FIXME: The libraries should be explicitly listed as CONTENT_LIBS_BIN_FILES
CONTENT_GAME0_BIN_FILES='
lib'
CONTENT_GAME_DATA_FILES='
Data
Linux
OGL
Stack.png
Win
DFCONFIG'

APP_MAIN_EXE='Stack.bin.x86'
APP_MAIN_ICON='Stack.png'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_BIN_ARCH='32'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'
## TODO: The list of dependencies on native libraries should be completed
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libGLU.so.1
libstdc++.so.6'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers

launchers_generation 'PKG_BIN'

# Build package

packages_generation
print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
